package testgrid;

import java.util.ArrayList;

import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.grid.Grid;
import com.vaadin.flow.component.notification.Notification;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.data.provider.ListDataProvider;
import com.vaadin.flow.data.renderer.ComponentRenderer;
import com.vaadin.flow.data.renderer.NativeButtonRenderer;
import com.vaadin.flow.router.AfterNavigationEvent;
import com.vaadin.flow.router.AfterNavigationObserver;
import com.vaadin.flow.router.Route;

@Route(value = "TestGrid")
public class TestGrid extends VerticalLayout
		implements AfterNavigationObserver
{
	private Grid<Person> personGrid;

	static class Person
	{
		String firstname;
		String surname;

		public Person(String firstname, String surname)
		{
			super();
			this.firstname = firstname;
			this.surname = surname;
		}

		public String getFirstname()
		{
			return firstname;
		}

		public String getSurname()
		{
			return surname;
		}

	}

	private final ArrayList<Person> entities = new ArrayList<>();

	public TestGrid()
	{
		entities.add(new Person("John", "Blogs"));
		entities.add(new Person("Will", "Smith"));
	}

	@Override
	public void afterNavigation(AfterNavigationEvent event)
	{
		buildUI();
	}

	void buildUI()
	{
		this.setId("baseListView");
		this.setSizeFull();
		this.setMargin(false);

		buildGrid();
	}

	private void buildGrid()
	{
		this.personGrid = new Grid<Person>();
		this.add(personGrid);

		personGrid.setSizeFull();
		this.expand(personGrid);
		this.setFlexGrow(1, personGrid);

		personGrid.setDataProvider(new ListDataProvider<Person>(entities));

		personGrid.addColumn(Person::getFirstname);
		personGrid.addColumn(Person::getSurname);

		personGrid.addColumn(new NativeButtonRenderer<Person>("Edit", (person) -> onEdit(person)))
		.setHeader("Native");

		personGrid.addColumn(new ComponentRenderer<>(item ->
			{
				return new Button("Edit");
			}))
				.setHeader("Edit");

	}

	private void onEdit(Person person)
	{
		Notification.show("On Native Edit clicked");
	}

}
